@@ -1,10 +1,15 @@
 # Use arg_nm to override the default name of the argument in case of an error message.
 assert_class <- function(x, class, or_null = FALSE, all = FALSE, package = NULL, envir = parent.frame(), arg_nm = NULL) {
+
   sx <- as.character(substitute(x, envir))
   if (length(sx) == 0 || !is.null(arg_nm)) {
     sx <- arg_nm %||% "argument"
   }
 
+  if (missing(x)) {
+    stop("input ", sx, " is missing", call. = FALSE)
+  }
+
   ok <- if (all) {
     all(vapply(class, function(i) inherits(x, i), NA))
   } else {
@@ -28,7 +33,6 @@ assert_class <- function(x, class, or_null = FALSE, all = FALSE, package = NULL,
   invisible(NULL)
 }
 
-
 assert_chart_sheet <- function(x) assert_class(x, c("wbChartSheet", "R6"), all = TRUE)
 assert_comment     <- function(x) assert_class(x, c("wbComment",    "R6"), all = TRUE)
 assert_color       <- function(x) assert_class(x, c("wbColour"),           all = TRUE)
@@ -37,6 +41,11 @@ assert_sheet_data  <- function(x) assert_class(x, c("wbSheetData",  "R6"), all =
 assert_workbook    <- function(x) assert_class(x, c("wbWorkbook",   "R6"), all = TRUE)
 assert_worksheet   <- function(x) assert_class(x, c("wbWorksheet",  "R6"), all = TRUE)
 
+assert_named_region <- function(x) {
+  if (grepl("^[A-Z]{1,3}[0-9]+$", x))
+    stop("name cannot look like a cell reference.")
+}
+
 match_oneof <- function(x, y, or_null = FALSE, several = FALSE, envir = parent.frame()) {
   sx <- as.character(substitute(x, envir))
 
@@ -53,28 +62,3 @@ match_oneof <- function(x, y, or_null = FALSE, several = FALSE, envir = parent.f
 
   y[m]
 }
-
-validate_color <- function(color = NULL, or_null = FALSE, envir = parent.frame()) {
-  sx <- as.character(substitute(color, envir))
-
-  if (identical(color, "none") && or_null) {
-    return(NULL)
-  }
-
-  # returns black
-  if (is.null(color)) {
-    if (or_null) return(NULL)
-    return("FF000000")
-  }
-
-  if (ind <- any(color %in% grDevices::colors())) {
-    color[ind] <- col2hex(color[ind])
-  }
-
-  if (any(!grepl("^#[A-Fa-f0-9]{6}$", color))) {
-    msg <- sprintf("`%s` ['%s'] is not a valid color", sx, color)
-    stop(simpleError(msg))
-  }
-
-  gsub("^#", "FF", toupper(color))
-}
