@@ -180,6 +180,10 @@ guess_col_type <- function(tt) {
   col_dte <- vapply(tt[!col_num], function(x) all(x == "h", na.rm = TRUE), NA)
   types[names(col_dte[col_dte])] <- 5
 
+  # or formula
+  col_fml <- vapply(tt[!col_num], function(x) all(x == "f", na.rm = TRUE), NA)
+  types[names(col_fml[col_fml])] <- 6
+
   types
 }
 
@@ -347,9 +351,9 @@ delete_data <- function(wb, sheet, cols, rows) {
   cc <- wb$worksheets[[sheet_id]]$sheet_data$cc
 
   if (is.numeric(cols)) {
-    sel <- cc$row_r %in% as.character(rows) & cc$c_r %in% int2col(cols)
+    sel <- cc$row_r %in% as.character(as.integer(rows)) & cc$c_r %in% int2col(cols)
   } else {
-    sel <- cc$row_r %in% as.character(rows) & cc$c_r %in% cols
+    sel <- cc$row_r %in% as.character(as.integer(rows)) & cc$c_r %in% cols
   }
 
   # clean selected entries of cc
