@@ -2,8 +2,8 @@ test_that("Deleting a Table Object", {
   wb <- wb_workbook()
   wb$add_worksheet("Sheet 1")
   wb$add_worksheet("Sheet 2")
-  wb$add_data_table(sheet = "Sheet 1", x = iris, tableName = "iris")
-  wb$add_data_table(sheet = 1, x = mtcars, tableName = "mtcars", startCol = 10)
+  wb$add_data_table(sheet = "Sheet 1", x = iris, table_name = "iris")
+  wb$add_data_table(sheet = 1, x = mtcars, table_name = "mtcars", start_col = 10)
 
 
   # Get table ----
@@ -38,8 +38,8 @@ test_that("Deleting a Table Object", {
 
   ## write same tables again ----
 
-  wb$add_data_table(sheet = 1, x = iris, tableName = "iris")
-  wb$add_data_table(sheet = 1, x = mtcars, tableName = "mtcars", startCol = 10)
+  wb$add_data_table(sheet = 1, x = iris, table_name = "iris")
+  wb$add_data_table(sheet = 1, x = mtcars, table_name = "mtcars", start_col = 10)
 
   expect_equal(wb$tables$tab_name, c("iris_openxlsx_deleted", "mtcars_openxlsx_deleted", "iris", "mtcars"))
   expect_equal(wb$tables$tab_sheet, c(0, 0, 1, 1))
@@ -72,7 +72,7 @@ test_that("Deleting a Table Object", {
   ))
 
   ## wb_remove_tables clears table object and all data
-  wb$add_data_table(sheet = 1, x = iris, tableName = "iris", startCol = 1)
+  wb$add_data_table(sheet = 1, x = iris, table_name = "iris", start_col = 1)
   temp <- temp_xlsx()
   wb_save(wb, temp)
   expect_equal(wb$worksheets[[1]]$tableParts, c("<tablePart r:id=\"rId2\"/>", "<tablePart r:id=\"rId3\"/>"), ignore_attr = TRUE)
@@ -104,8 +104,8 @@ test_that("Save and load Table Deletion", {
   wb <- wb_workbook()
   wb$add_worksheet("Sheet 1")
   wb$add_worksheet("Sheet 2")
-  wb$add_data_table(sheet = "Sheet 1", x = iris, tableName = "iris")
-  wb$add_data_table(sheet = 1, x = mtcars, tableName = "mtcars", startCol = 10)
+  wb$add_data_table(sheet = "Sheet 1", x = iris, table_name = "iris")
+  wb$add_data_table(sheet = 1, x = mtcars, table_name = "mtcars", start_col = 10)
 
 
   ###################################################################################
@@ -134,8 +134,8 @@ test_that("Save and load Table Deletion", {
   wb <- wb_workbook()
   wb$add_worksheet("Sheet 1")
   wb$add_worksheet("Sheet 2")
-  wb$add_data_table(sheet = "Sheet 1", x = iris, tableName = "iris")
-  wb$add_data_table(sheet = 1, x = mtcars, tableName = "mtcars", startCol = 10)
+  wb$add_data_table(sheet = "Sheet 1", x = iris, table_name = "iris")
+  wb$add_data_table(sheet = 1, x = mtcars, table_name = "mtcars", start_col = 10)
 
   ## remove iris and re-write it
   wb$remove_tables(sheet = 1, table = "iris")
@@ -158,9 +158,9 @@ test_that("Save and load Table Deletion", {
   wb <- wb_workbook()
   wb$add_worksheet("Sheet 1")
   wb$add_worksheet("Sheet 2")
-  wb$add_data_table(sheet = "Sheet 1", x = iris, tableName = "iris")
-  wb$add_data_table(sheet = 1, x = mtcars, tableName = "mtcars", startCol = 10)
-  wb$add_data_table(sheet = 2, x = mtcars, tableName = "mtcars2", startCol = 3)
+  wb$add_data_table(sheet = "Sheet 1", x = iris, table_name = "iris")
+  wb$add_data_table(sheet = 1, x = mtcars, table_name = "mtcars", start_col = 10)
+  wb$add_data_table(sheet = 2, x = mtcars, table_name = "mtcars2", start_col = 3)
 
   wb$remove_tables(sheet = 1, table = "iris")
   wb$remove_tables(sheet = 1, table = "mtcars")
@@ -179,8 +179,8 @@ test_that("Save and load Table Deletion", {
 
 
   ## write tables back in
-  wb$add_data_table(sheet = "Sheet 1", x = iris, tableName = "iris")
-  wb$add_data_table(sheet = 1, x = mtcars, tableName = "mtcars", startCol = 10)
+  wb$add_data_table(sheet = "Sheet 1", x = iris, table_name = "iris")
+  wb$add_data_table(sheet = 1, x = mtcars, table_name = "mtcars", start_col = 10)
 
   expect_equal(nrow(wb$tables), 3L)
   expect_equal(wb$tables$tab_name, c("mtcars2", "iris", "mtcars"))
