@@ -281,7 +281,7 @@ test_that("write cells without data", {
   expect_equal(exp, got)
 
   sheet <- paste0(tmp_dir, "/xl/worksheets/sheet1.xml")
-  exp <- "<sheetData><row r=\"2\"><c r=\"B2\"/><c r=\"C2\"/></row><row r=\"3\"><c r=\"B3\"/><c r=\"C3\"/></row></sheetData>"
+  exp <- "<sheetData><row r=\"2\"/><row r=\"3\"/></sheetData>"
   got <- xml_node(sheet, "worksheet", "sheetData")
   expect_equal(exp, got)
 
